summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/stdtransactionmatched.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/stdtransactionmatched.h')
-rw-r--r--kmymoney2/widgets/stdtransactionmatched.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/kmymoney2/widgets/stdtransactionmatched.h b/kmymoney2/widgets/stdtransactionmatched.h
index 599e6e0..e8959a9 100644
--- a/kmymoney2/widgets/stdtransactionmatched.h
+++ b/kmymoney2/widgets/stdtransactionmatched.h
@@ -20,7 +20,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qbrush.h>
+#include <tqbrush.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -41,7 +41,7 @@ class StdTransactionMatched : public StdTransaction
static const int m_additionalRows = 3;
public:
- StdTransactionMatched(Register* parent, const MyMoneyTransaction& transaction, const MyMoneySplit& split, int uniqueId);
+ StdTransactionMatched(Register* tqparent, const MyMoneyTransaction& transaction, const MyMoneySplit& split, int uniqueId);
virtual ~StdTransactionMatched() {}
virtual const char* className(void) { return "StdTransactionMatched"; }
@@ -58,34 +58,34 @@ public:
* - textRect (area covering the text)
* - color of the pen to do the painting of text and lines
*
* @param painter pointer to the QPainter object
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
* @param cellRect ref to QRect object receiving the area information for the cell
* @param textRect ref to QRect object receiving the area information for the text
* @param cg ref to QColorGroup object receiving the color information to be used
* @param brush ref to QBrush object receiveing the brush information to be used
*/
- virtual bool paintRegisterCellSetup(QPainter* painter, int& row, int& col, QRect& cellRect, QRect& textRect, QColorGroup& cg, QBrush& brush);
+ virtual bool paintRegisterCellSetup(TQPainter* painter, int& row, int& col, TQRect& cellRect, TQRect& textRect, TQColorGroup& cg, TQBrush& brush);
- virtual void paintRegisterGrid(QPainter* painter, int row, int col, const QRect& r, const QColorGroup& cg) const;
+ virtual void paintRegisterGrid(TQPainter* painter, int row, int col, const TQRect& r, const TQColorGroup& cg) const;
#if 0
- virtual void paintRegisterCell(QPainter* painter, int row, int col, const QRect& r, bool selected, const QColorGroup& cg);
+ virtual void paintRegisterCell(TQPainter* painter, int row, int col, const TQRect& r, bool selected, const TQColorGroup& cg);
- bool formCellText(QString& txt, int& align, int row, int col, QPainter* painter = 0);
+ bool formCellText(TQString& txt, int& align, int row, int col, TQPainter* painter = 0);
int numColsForm(void) const { return 4; }
- void arrangeWidgetsInForm(QMap<QString, QWidget*>& editWidgets);
- void arrangeWidgetsInRegister(QMap<QString, QWidget*>& editWidgets);
- void tabOrderInForm(QWidgetList& tabOrderWidgets) const;
- void tabOrderInRegister(QWidgetList& tabOrderWidgets) const;
+ void arrangeWidgetsInForm(TQMap<TQString, TQWidget*>& editWidgets);
+ void arrangeWidgetsInRegister(TQMap<TQString, TQWidget*>& editWidgets);
+ void tabOrderInForm(TQWidgetList& tabOrderWidgets) const;
+ void tabOrderInRegister(TQWidgetList& tabOrderWidgets) const;
int numRowsRegister(bool expanded) const;
#endif
- void registerCellText(QString& txt, int& align, int row, int col, QPainter* painter = 0);
+ void registerCellText(TQString& txt, int& align, int row, int col, TQPainter* painter = 0);
/**
* Provided for internal reasons. No API change. See RegisterItem::numRowsRegister(bool)
@@ -58,34 +58,34 @@ public:
* - color of the pen to do the painting of text and lines
*
- * @param painter pointer to the QPainter object
+ * @param painter pointer to the TQPainter object
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
@@ -58,34 +58,34 @@ public:
* @param row vertical index of cell in register
* @param col horizontal index of cell in register
- * @param cellRect ref to QRect object receiving the area information for the cell
- * @param textRect ref to QRect object receiving the area information for the text
- * @param cg ref to QColorGroup object receiving the color information to be used
- * @param brush ref to QBrush object receiveing the brush information to be used
+ * @param cellRect ref to TQRect object receiving the area information for the cell
+ * @param textRect ref to TQRect object receiving the area information for the text
+ * @param cg ref to TQColorGroup object receiving the color information to be used
+ * @param brush ref to TQBrush object receiveing the brush information to be used
*/